@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -93,6 +93,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
         final String metaValue_ban = "balinesiska";
         final String metaValue_bax = "bamunska";
         final String metaValue_bug = "buginesiska";
+        final String metaValue_ccp = "chakma";
         final String metaValue_cop = "koptiska";
         final String metaValue_gez = "etiopiska";
         final String metaValue_got = "gotiska";
@@ -103,6 +104,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
         final String metaValue_peo = "fornpersiska";
         final String metaValue_phn = "feniciska";
         final String metaValue_saz = "saurashtra";
+        final String metaValue_sog = "sogdiska";
         final String metaValue_syr = "syriska";
         final String metaValue_uga = "ugaritiska";
         final String metaValue_vai = "vaj";
@@ -121,10 +123,12 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "Njiva-dialekt" },
             { "xmf", "mingrelianska" },
+            { "ccp", metaValue_ccp },
             { "egy", "fornegyptiska" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
             { "tem", "temne" },
+            { "Medf", "medefaidrin" },
             { "type.nu.sind", "khudawidiska siffror" },
             { "teo", "teso" },
             { "rap", "rapanui" },
@@ -167,6 +171,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "kum", "kumykiska" },
             { "BE", "Belgien" },
             { "gmh", "medelh\u00f6gtyska" },
+            { "Sogo", "gammalsogdiska" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgarien" },
             { "BH", "Bahrain" },
@@ -189,6 +194,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "BZ", "Belize" },
             { "Visp", "synligt tal" },
             { "type.ca.persian", "persisk kalender" },
+            { "%%CREISS", "croissant-occitanska" },
             { "type.nu.hebr", "hebreiska taltecken" },
             { "CA", "Kanada" },
             { "CC", "Kokos\u00f6arna" },
@@ -197,7 +203,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "CF", "Centralafrikanska republiken" },
             { "CG", "Kongo-Brazzaville" },
             { "CH", "Schweiz" },
-            { "CI", "Elfenbenskusten" },
+            { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Cook\u00f6arna" },
             { "CL", "Chile" },
             { "Kthi", "kaithiska" },
@@ -218,6 +224,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Pauc", "Pau Cin Hau-skrift" },
             { "vls", "v\u00e4stflaml\u00e4ndska" },
             { "%%RIGIK", "klassisk volap\u00fck" },
+            { "Sogd", metaValue_sog },
             { "DE", "Tyskland" },
             { "goh", "fornh\u00f6gtyska" },
             { "ace", "acehnesiska" },
@@ -328,6 +335,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "zxx", "inget spr\u00e5kligt inneh\u00e5ll" },
             { "Jurc", "jurchenska" },
             { "tly", "talysh" },
+            { "%%VIVARAUP", "vivaroalpinska (occitanska)" },
             { "pdt", "mennonitisk l\u00e5gtyska" },
             { "de_AT", "\u00f6sterrikisk tyska" },
             { "Vaii", metaValue_vai },
@@ -425,6 +433,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "LK", "Sri Lanka" },
             { "akk", "akkadiska" },
             { "cop", metaValue_cop },
+            { "Hmnp", "nyiakeng puachue hmong" },
             { "LR", "Liberia" },
             { "esu", "centralalaskisk jupiska" },
             { "LS", "Lesotho" },
@@ -455,7 +464,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "MH", "Marshall\u00f6arna" },
             { "ale", "aleutiska" },
             { "type.nu.vaii", "vai-siffror" },
-            { "MK", "Makedonien" },
+            { "MK", "Nordmakedonien" },
             { "type.nu.mathdbl", "matematiska siffror med dubbelstreck" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
@@ -480,7 +489,8 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "MZ", "Mo\u00e7ambique" },
             { "Phli", "tidig pahlavi" },
             { "NA", "Namibia" },
-            { "202", "202" },
+            { "%%ARANES", "aranesiska (occitanska)" },
+            { "202", "Subsahariska Afrika" },
             { "type.ca.hebrew", "hebreisk kalender" },
             { "type.co.dictionary", "ordbokssorteringsordning" },
             { "NC", "Nya Kaledonien" },
@@ -510,10 +520,12 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Mero", "meroitiska" },
             { "crh", "krimtatariska" },
             { "ang", "fornengelska" },
+            { "%%GRMISTR", "Mistral-occitanska" },
             { "OM", "Oman" },
             { "%%PETR1708", "1708 \u00e5rs stavning" },
             { "anp", "angika" },
             { "crs", "seychellisk kreol" },
+            { "type.nu.hmnp", "nyiakeng puachue hmong-siffror" },
             { "Xpeo", metaValue_peo },
             { "type.nu.hmng", "pahawh hmong-siffror" },
             { "PA", "Panama" },
@@ -526,6 +538,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "PG", "Papua Nya Guinea" },
             { "PH", "Filippinerna" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "Nice-occitanska" },
             { "PL", "Polen" },
             { "ewo", "ewondo" },
             { "PM", "S:t Pierre och Miquelon" },
@@ -554,6 +567,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "tvl", "tuvaluanska" },
             { "Tavt", "tai viet" },
             { "%%SOTAV", "sotavento-dialekt" },
+            { "Maka", "makasariska" },
             { "001", "v\u00e4rlden" },
             { "002", "Afrika" },
             { "njo", "ao-naga" },
@@ -565,6 +579,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "pnt", "pontiska" },
             { "Rjng", "rejang" },
             { "009", "Oceanien" },
+            { "Elym", "elymaiska" },
             { "%%SURSILV", "sursilvan-dialekt" },
             { "RO", "Rum\u00e4nien" },
             { "RS", "Serbien" },
@@ -632,6 +647,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "TC", "Turks- och Caicos\u00f6arna" },
             { "yav", "yangben" },
             { "TD", "Tchad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Franska sydterritorierna" },
             { "ase", "amerikanskt teckenspr\u00e5k" },
             { "TG", "Togo" },
@@ -679,6 +695,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "US", "USA" },
             { "haw", "hawaiiska" },
             { "%%1959ACAD", "1959 \u00e5rs stavning" },
+            { "%%IVANCHOV", "bulgariska i 1899 \u00e5rs stavning" },
             { "type.co.gb2312han", "gb2312-sorteringsordning" },
             { "UY", "Uruguay" },
             { "prg", "fornpreussiska" },
@@ -693,6 +710,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Brittiska Jungfru\u00f6arna" },
             { "VI", "Amerikanska Jungfru\u00f6arna" },
+            { "%%LEMOSIN", "Limousin-occitanska" },
             { "Soyo", "soyombo" },
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
@@ -719,7 +737,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.mtei", "meetei mayek-siffror" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "fejkade accenter (f\u00f6r test)" },
             { "war", "waray" },
+            { "XB", "fejkad bidi (f\u00f6r test)" },
             { "awa", "awadhi" },
             { "061", "Polynesien" },
             { "%%KSCOR", "standardstavning" },
@@ -764,7 +784,10 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.telu", "telugiska siffror" },
             { "lou", "louisiana-kreol" },
             { "loz", "lozi" },
+            { "%%FONKIRSH", "Kirshenbaums fonetiska alfabet" },
             { "Nkgb", "naxi geba" },
+            { "%%ASANTE", "asante (twi)" },
+            { "%%AUVERN", "auvergniska (occitanska)" },
             { "jmc", "kimashami" },
             { "hif", "Fiji-hindi" },
             { "type.nu.hansfin", "f\u00f6renklat kinesiskt finansiellt stavade tal" },
@@ -783,6 +806,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "nwc", "klassisk newariska" },
             { "udm", "udmurtiska" },
             { "Khmr", "khmeriska" },
+            { "%%FONNAPA", "nordamerikanskt fonetiskt alfabet" },
             { "type.ca.islamic-rgsa", "islamisk kalender, Saudi-Arabien" },
             { "Limb", "limbu" },
             { "sad", "sandawe" },
@@ -810,6 +834,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.d0.fwidth", "till helbreda" },
             { "sbp", "sangu" },
             { "lui", "luise\u00f1o" },
+            { "%%GRITAL", "italiensk-inspirerad occitanska" },
             { "nyn", "nyankole" },
             { "nym", "nyamwezi" },
             { "lun", "lunda" },
@@ -837,6 +862,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "scn", "sicilianska" },
             { "aa", "afar" },
             { "ab", "abchaziska" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak-toba" },
             { "ae", metaValue_ae },
             { "af", "afrikaans" },
@@ -858,7 +884,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "sdh", "sydkurdiska" },
             { "ay", "aymara" },
             { "az", "azerbajdzjanska" },
+            { "Rohg", "hanifiska" },
             { "Khoj", "khojkiska" },
+            { "%%CISAUP", "cisalpinska (occitanska)" },
             { "%%OSOJS", "Osojane-dialekt" },
             { "%%UNIFON", "unifon-skrift" },
             { "ba", "basjkiriska" },
@@ -882,7 +910,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Nkoo", metaValue_nqo },
             { "sel", "selkup" },
             { "ca", "katalanska" },
-            { "ses", "Gao-songhay" },
+            { "ses", "Gao-songhai" },
             { "ce", "tjetjenska" },
             { "ch", "chamorro" },
             { "%%REVISED", "reformerad stavning" },
@@ -957,10 +985,13 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.m0.bgn", "enligt USA:s geografiska namnkommitt\u00e9" },
             { "umb", "umbundu" },
             { "fr", "franska" },
+            { "%%AKUAPEM", "akapuem (twi)" },
             { "sid", "sidamo" },
             { "fy", "v\u00e4stfrisiska" },
             { "ga", "iriska" },
+            { "Wcho", "wancho" },
             { "gd", "skotsk g\u00e4liska" },
+            { "Gong", "gunjalgondiska" },
             { "gl", "galiciska" },
             { "Gonm", "masaram-gondi" },
             { "gn", "guaran\u00ed" },
@@ -990,6 +1021,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "id", "indonesiska" },
             { "type.nu.tibt", "tibetanska siffror" },
             { "ie", "interlingue" },
+            { "%%GASCON", "Gascogne-occitanska" },
             { "ig", "igbo" },
             { "ii", "szezuan i" },
             { "frm", "medelfranska" },
@@ -1050,7 +1082,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "ku", "kurdiska" },
             { "kv", "kome" },
             { "kw", "korniska" },
-            { "ky", "kirgisiska" },
+            { "ky", "kirgiziska" },
             { "snk", "soninke" },
             { "Mult", "multaniska" },
             { "la", "latin" },
@@ -1068,8 +1100,8 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.lana", "tai tham hora-siffror" },
             { "lt", "litauiska" },
             { "lu", "luba-katanga" },
+            { "sog", metaValue_sog },
             { "lv", "lettiska" },
-            { "sog", "sogdiska" },
             { "mg", "malagassiska" },
             { "mh", "marshalliska" },
             { "type.co.ducet", "grundl\u00e4ggande Unicode-sorteringsordning" },
@@ -1087,7 +1119,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "mde", "maba" },
             { "dsb", "l\u00e5gsorbiska" },
             { "Armi", "imperisk arameiska" },
-            { "na", "nauriska" },
+            { "na", "nauruanska" },
             { "type.co.search", "allm\u00e4n s\u00f6kning" },
             { "nb", "norskt bokm\u00e5l" },
             { "nd", "nordndebele" },
@@ -1097,6 +1129,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "nl", "nederl\u00e4ndska" },
             { "nn", "nynorska" },
             { "no", "norska" },
+            { "%%PROVENC", "provensalska" },
             { "nr", "sydndebele" },
             { "type.nu.modi", "modi-siffror" },
             { "Osge", metaValue_osa },
@@ -1215,6 +1248,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%NEDIS", "natisonsk dialekt" },
             { "sv", "svenska" },
             { "sw", "swahili" },
+            { "type.nu.wcho", "wanchosiffror" },
             { "type.nu.hantfin", "traditionellt kinesiskt finansiellt stavade tal" },
             { "ibb", "ibibio" },
             { "iba", "ibanska" },
@@ -1239,9 +1273,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "japanskt stavade tal" },
             { "tr", "turkiska" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "shimaor\u00e9" },
-            { "Cakm", "chakma" },
             { "tt", "tatariska" },
             { "%%XSISTEMO", "x-system" },
             { "dyu", "dyula" },
@@ -1250,6 +1284,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%BISKE", "Bila-dialekt" },
             { "150", "Europa" },
             { "151", "\u00d6steuropa" },
+            { "type.nu.rohg", "hanifisiffror" },
             { "type.nu.mathsanb", "matematiska siffror i sans-serif fetstil" },
             { "154", "Nordeuropa" },
             { "dzg", "dazaga" },
@@ -1276,7 +1311,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.ca.roc", "kinesiska republikens kalender" },
             { "vi", "vietnamesiska" },
             { "kho", "khotanesiska" },
-            { "khq", "Timbuktu-songhoy" },
+            { "khq", "Timbuktu-songhai" },
             { "key.hc", "12- eller 24-timmarsklocka" },
             { "%%TARASK", "Taraskievika-stavning" },
             { "vo", "volap\u00fck" },
@@ -1285,12 +1320,14 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.mathsans", "matematiska siffror i sans-serif" },
             { "Osma", "osmanja" },
             { "quc", "quich\u00e9" },
+            { "type.nu.gonm", "masaramgondiska siffror" },
             { "qug", "Chimborazo-h\u00f6glandskichwa" },
             { "Newa", metaValue_new },
             { "gaa", "g\u00e3" },
             { "wa", "vallonska" },
             { "gag", "gagauziska" },
             { "syr", metaValue_syr },
+            { "type.nu.gong", "gunjalagondiska siffror" },
             { "Grek", metaValue_el },
             { "gan", "gan" },
             { "kiu", "kirmanjki" },
@@ -1311,11 +1348,13 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "mni", "manipuri" },
             { "Latn", "latinska" },
             { "Latg", "gaeliskt latin" },
+            { "Nand", "nandinagari" },
             { "type.nu.hans", "f\u00f6renklat kinesiskt stavade tal" },
             { "type.nu.hant", "traditionellt kinesiskt stavade tal" },
             { "xh", "xhosa" },
             { "type.nu.romanlow", "sm\u00e5 romerska taltecken" },
             { "byn", "blin" },
+            { "Dogr", "dogriska" },
             { "%%PAMAKA", "Pamaka-dialekt" },
             { "Lyci", "lykiska" },
             { "osa", metaValue_osa },
@@ -1349,6 +1388,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%MONOTON", "monotonisk stavning" },
             { "Geor", metaValue_ka },
             { "Shrd", "sharada" },
+            { "%%LENGADOC", "languedociska" },
             { "kmb", "kimbundu" },
             { "type.nu.jpanfin", "japanskt finansiellt stavade tal" },
             { "Cham", "cham" },
@@ -1383,6 +1423,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Sund", metaValue_su },
             { "vep", "veps" },
             { "kpe", "kpelle" },
+            { "%%GRCLASS", "klassisk occitanska" },
             { "type.nu.khmr", "khmeriska siffror" },
             { "Tirh", "tirhuta" },
             { "ilo", "iloko" },
@@ -1408,6 +1449,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "inh", "ingusjiska" },
             { "krj", "kinaray-a" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karelska" },
             { "%%OXENDICT", "Oxford-stavning" },
             { "efi", "efik" },
